@@ -161,7 +161,9 @@ def scan_use(repo_root: str, err: Callable[[str], None]):
 def scan_profiles(repo_root: str, err: Callable[[str], None]):
     # Check profiles/profiles.yaml
     path = os.path.join(repo_root, "profiles", "profiles.yaml")
-    archs = read_list(os.path.join(repo_root, "profiles", "arch.list"))
+    archs_path = os.path.join(repo_root, "profiles", "arch.list")
+    if os.path.exists(archs_path):
+        archs = read_list(archs_path)
     if os.path.exists(path):
         keywords = parse_yaml_dict_dict(path)
         for keyword, profiles in keywords.items():
