@@ -25,6 +25,16 @@ from .pyconf import (
 )
 
 
+def get_config_value(key: str, default: Optional[Any] = None):
+    """
+    Parses the user's configuration, overriding defaults from their profile
+
+    returns:
+        The config value matching key, or default if it was not specified
+    """
+    return get_config().get(key, default)
+
+
 @prefix_aware_cache
 def get_config() -> Dict[str, Any]:
     """
@@ -60,14 +70,18 @@ def get_config() -> Dict[str, Any]:
         else:
             _create_config_placeholder()
 
-    # Set defaults
+    # Set defaults and add to os.environ (for use in portmodlib)
     for key in __OVERRIDE_KEYS:
-        if key not in total_config:
+        if not total_config.get(key):
             total_config[key] = ""
+        elif isinstance(total_config[key], (str, bool)) and total_config[key]:
+            os.environ[key] = str(total_config[key])
 
     for key in __COLLAPSE_KEYS:
-        if key not in total_config:
+        if not total_config.get(key):
             total_config[key] = set()
+        elif isinstance(total_config[key], (str, bool)) and total_config[key]:
+            os.environ[key] = str(total_config[key])
 
     return total_config
 
@@ -83,7 +97,7 @@ def config_to_string(config: Dict) -> str:
     return "\n".join(lines)
 
 
-def set_config_value(key: str, value: str) -> Optional[str]:
+def set_config_value(key: str, value: str, path: Optional[str] = None) -> Optional[str]:
     """
     Sets the given key-value pair in portmod.conf
 
@@ -94,8 +108,11 @@ def set_config_value(key: str, value: str) -> Optional[str]:
         from redbaron import RedBaron
         from redbaron.nodes import AssignmentNode, NameNode
 
+    if not path:
+        path = env.prefix().CONFIG
+
     old = None
-    with open(env.prefix().CONFIG, "r") as file:
+    with open(path, "r") as file:
         node = RedBaron(file.read())
 
         string = '"' + value + '"'
@@ -112,7 +129,7 @@ def set_config_value(key: str, value: str) -> Optional[str]:
         if not old:
             node.append(f"{key} = {string}")
 
-        with open(env.prefix().CONFIG, "w") as file:
+        with open(path, "w") as file:
             file.write(node.dumps())
 
     get_config.cache_clear()  # type: ignore
