@@ -149,7 +149,7 @@ def sandbox_execute(
         environ["TMP"] = permissions.tmp
         os.makedirs(permissions.tmp, exist_ok=True)
 
-    # ensure path added at runtime are avalaible
+    # ensure paths added at runtime are available
     if "PYTHONPATH" not in environ:
         environ["PYTHONPATH"] = ""
     if sys.platform == "win32":
@@ -175,12 +175,21 @@ def sandbox_execute(
                 "/var",
             }
 
-        ro_paths, rw_paths, symlinks = get_paths(ro_paths, rw_paths)
+        ro_paths, rw_paths, syms = get_paths(ro_paths, rw_paths)
 
         ro_bind: List[str] = sum([["--ro-bind", path, path] for path in ro_paths], [])
         bind: List[str] = sum([["--bind", path, path] for path in rw_paths], [])
+
+        sym_dests = []
+        for path in syms:
+            linkpath = os.readlink(path)
+            if os.path.isabs(linkpath):
+                sym_dests.append(linkpath)
+            else:
+                sym_dests.append(os.path.join(os.path.dirname(path), linkpath))
+
         symlink: List[str] = sum(
-            [["--symlink", os.readlink(path), path] for path in symlinks], []
+            [["--ro-bind", dpath, path] for dpath, path in zip(sym_dests, syms)], []
         )
 
         sandbox_command = (
