@@ -55,25 +55,27 @@ class Env:
     class Prefix:
         REPOS: List["portmod.repo.Repo"]
 
-        def __init__(self, prefix: str):
+        def __init__(self, prefix_name: str):
             from portmod.prefix import get_prefixes
 
-            if prefix not in get_prefixes():
-                raise Exception(l10n("invalid-prefix", prefix=prefix))
+            if prefix_name not in get_prefixes():
+                raise Exception(l10n("invalid-prefix", prefix=prefix_name))
 
-            self.ARCH = get_prefixes()[prefix]
-            self.CONFIG_DIR = os.path.join(env.CONFIG_DIR, prefix)
+            prefix = get_prefixes()[prefix_name]
+
+            self.ARCH = prefix.arch
+            self.CONFIG_DIR = os.path.join(env.CONFIG_DIR, prefix_name)
             self.SET_DIR = os.path.join(self.CONFIG_DIR, "sets")
             self.CONFIG = os.path.join(self.CONFIG_DIR, "portmod.conf")
 
-            self.ROOT = os.path.join(env.DATA_DIR, prefix)
+            self.ROOT = prefix.path or os.path.join(env.DATA_DIR, prefix_name)
             self.MODULES_DIR = os.path.join(self.ROOT, "modules")
             self.VARIABLE_DATA = os.path.join(self.ROOT, "var")
             self.VAR_SET_DIR = os.path.join(self.VARIABLE_DATA, "sets")
             self.INSTALLED_DB = os.path.join(self.VARIABLE_DATA, "db")
             self.NEWS_DIR = os.path.join(self.VARIABLE_DATA, "news")
 
-            self.CACHE_DIR = os.path.join(env.CACHE_DIR, "prefix", prefix)
+            self.CACHE_DIR = os.path.join(env.CACHE_DIR, "prefix", prefix_name)
             self.PYBUILD_INSTALLED_CACHE = os.path.join(self.CACHE_DIR, "pybuild")
             self.CONFIG_PROTECT_DIR = os.path.join(self.CACHE_DIR, "cfg_protect")
             self.LOCAL_MODS = os.path.join(self.ROOT, "local")
