@@ -56,6 +56,7 @@ def belongs(path: str, case_sensitive: bool = True) -> Optional[InstalledPybuild
     for pkg in load_all_installed():
         if pkg.get_contents().get(normpath, case_sensitive=case_sensitive):
             return pkg
+
     return None
 
 
@@ -194,6 +195,9 @@ def remove_pkg(pkg: InstalledPybuild, reinstall: bool = False):
             realentry = ManifestEntry.from_path(FileType.MISC, fullpath, path)
             if realentry == entry:
                 os.remove(fullpath)
+                if os.path.exists(fullpath + ".orig"):
+                    info(l10n("restoring-file-backup", path=fullpath + ".orig"))
+                    os.rename(fullpath + ".orig", fullpath)
                 # Remove the parent directory. If it is non-empty, this will fail.
                 try:
                     os.removedirs(os.path.dirname(fullpath))
@@ -375,7 +379,9 @@ def install_pkg(mod: Pybuild, use_flags: Set[str]):
                 overwrite_all = True
 
             if result in (l10n("yes-short"), l10n("always-short")) or overwrite_all:
-                info(l10n("pkg-file-conflict-overwrite", file=dst))
+                preserved = dst + ".orig"
+                info(l10n("pkg-file-conflict-overwrite", file=dst, preserved=preserved))
+                os.rename(dst, preserved)
                 _patch_file(src, dst, overwrite=True, move_function=shutil.copy2)
 
     state.ROOT = final_install
