@@ -5,6 +5,7 @@
 Module for performing bulk queries on the mod database and repositories
 """
 
+import logging
 import re
 import sys
 from collections import defaultdict
@@ -23,7 +24,7 @@ from typing import (
 )
 
 from portmodlib.atom import Atom, FQAtom, atom_sat
-from portmodlib.colour import blue, bright, green, lblue, lgreen, red, yellow
+from portmodlib.colour import blue, bright, cyan, green, lblue, lgreen, red, yellow
 from portmodlib.l10n import l10n
 from portmodlib.usestr import parse_usestr
 
@@ -251,21 +252,17 @@ def get_flag_string(
 
 
 def display_search_results(
-    mods: Iterable[Pybuild], summarize: bool = True, file=sys.stdout
+    package_groups: List[List[Pybuild]],
+    summarize: bool = True,
+    numbers: bool = False,
+    file=sys.stdout,
 ):
     """
     Prettily formats a list of mods for use in search results
     """
-    groupedmods: Dict[str, List[Pybuild]] = {}
-    for mod in mods:
-        if groupedmods.get(mod.CPN) is None:
-            groupedmods[mod.CPN] = [mod]
-        else:
-            groupedmods[mod.CPN].append(mod)
-
-    sortedgroups = sorted(groupedmods.values(), key=lambda group: group[0].NAME)
-
-    for group in sortedgroups:
+    count = 0
+    for group in package_groups:
+        count += 1
         sortedmods = sorted(group, key=lambda mod: mod.PV)
         newest = get_newest(group)
         installed = load_installed_pkg(Atom(newest.CPN))
@@ -378,41 +375,60 @@ def display_search_results(
         homepage_str = "\n                 ".join(newest.HOMEPAGE.split())
         mod_metadata = get_package_metadata(mod)
 
-        print(
-            "{}  {}".format(green("*"), bright(newest.CPN)),
-            "       {} {}".format(green(l10n("package-name")), mod.NAME),
-            "       {} {}".format(
-                green(l10n("package-available-versions")), version_str
-            ),
-            "       {} {}".format(
-                green(l10n("package-installed-version")), installed_str
-            ),
-            "       {} {}".format(green(l10n("package-size-of-files")), download),
-            "       {} {}".format(green(l10n("package-homepage")), homepage_str),
-            "       {} {}".format(
-                green(l10n("package-description")), str_squelch_sep(newest.DESC)
-            ),
-            "       {} {}".format(green(l10n("package-license")), newest.LICENSE),
-            sep="\n",
-            file=file,
-        )
-
-        if mod_metadata and mod_metadata.upstream:
-            maintainers = mod_metadata.upstream.maintainer
-            if maintainers:
-                maintainers_display_strings = get_maintainer_string(maintainers)
-                print(
-                    "       {} {}".format(
-                        green(l10n("package-upstream-author")),
-                        maintainers_display_strings,
-                    ),
-                    file=file,
-                )
-
-        print(file=file)
+        if logging.root.level <= logging.DEBUG:
+            print(
+                "{} {}  {}".format(
+                    cyan(count) if numbers else "", green("*"), bright(newest.CPN)
+                ),
+                "       {} {}".format(green(l10n("package-name")), mod.NAME),
+                "       {} {}".format(
+                    green(l10n("package-available-versions")), version_str
+                ),
+                "       {} {}".format(
+                    green(l10n("package-installed-version")), installed_str
+                ),
+                "       {} {}".format(green(l10n("package-size-of-files")), download),
+                "       {} {}".format(green(l10n("package-homepage")), homepage_str),
+                "       {} {}".format(
+                    green(l10n("package-description")), str_squelch_sep(newest.DESC)
+                ),
+                "       {} {}".format(green(l10n("package-license")), newest.LICENSE),
+                sep="\n",
+                file=file,
+            )
+            if mod_metadata and mod_metadata.upstream:
+                maintainers = mod_metadata.upstream.maintainer
+                if maintainers:
+                    maintainers_display_strings = get_maintainer_string(maintainers)
+                    print(
+                        "       {} {}".format(
+                            green(l10n("package-upstream-author")),
+                            maintainers_display_strings,
+                        ),
+                        file=file,
+                    )
+            print(file=file)
+        else:
+            print(
+                "{} {}  {}".format(
+                    cyan(count) if numbers else "", green("*"), bright(newest.CPN)
+                ),
+                "       {} {}".format(
+                    green(l10n("package-available-versions")), version_str
+                ),
+                "       {} {}".format(
+                    green(l10n("package-installed-version")), installed_str
+                ),
+                "       {} {}".format(green(l10n("package-homepage")), homepage_str),
+                "       {} {}".format(
+                    green(l10n("package-description")), str_squelch_sep(newest.DESC)
+                ),
+                sep="\n",
+                file=file,
+            )
 
     if summarize:
-        print("\n" + l10n("packages-found", num=len(sortedgroups)), file=file)
+        print("\n" + l10n("packages-found", num=len(package_groups)), file=file)
 
 
 class FlagDesc:
