@@ -113,9 +113,14 @@ def get_repo_root(path: str) -> Optional[str]:
 
 def has_repo(name: str) -> bool:
     """Returns true iff the repo exists"""
-    for repo in env.prefix().REPOS:
-        if repo.name == name:
-            return True
+    if env.PREFIX_NAME:
+        for repo in env.prefix().REPOS:
+            if repo.name == name:
+                return True
+    else:
+        for repo in env.REPOS:
+            if repo.name == name:
+                return True
     return False
 
 
