@@ -28,38 +28,58 @@ def get_keywords(atom):
     return get_flags(keyword_file, atom).union(ACCEPT_KEYWORDS)
 
 
+def accepts_stable(arch, keywords):
+    return (
+        # Package is always visible
+        "**" in keywords
+        # Package is visible if any architecture is stable
+        or (
+            "*" in keywords
+            and any(x not in ("~*", "*") and x[0] not in ("-", "~") for x in keywords)
+        )
+        # Package is explicitly keyworded as stable for this architecture
+        or any([keyword == arch for keyword in keywords])
+    )
+
+
 def accepts_testing(arch, keywords):
-    return any([keyword == "~" + arch or keyword == arch for keyword in keywords])
+    return (
+        accepts_stable(arch, keywords)
+        # Package is explicitly keyworded as testing for this architecture
+        or any(keyword == f"~{arch}" for keyword in keywords)
+        # Package is visible if any architecture is testing
+        or (
+            "~*" in keywords
+            and any(x not in ("~*", "*") and x[0] != "-" for x in keywords)
+        )
+    )
 
 
 def accepts(accept_keywords, keywords):
     for keyword in accept_keywords:
-        if keyword.startswith("~"):
-            # Accepts testing on this architecture. Valid if keywords contains either
-            # testing or stable for this keyword
-            if keyword in keywords or keyword[1:] in keywords:
-                return True
-        elif keyword == "*":
+        if keyword == "*":
             # Accepts stable on all architectures. Valid if keywords contains a stable
             # keyword for any keyword
-            if any(
-                [
-                    not keyword.startswith("~") and not keyword.startswith("*")
-                    for keyword in keywords
-                ]
-            ):
+            if any(keyword[0] not in ("~", "*", "-") for keyword in keywords):
                 return True
         elif keyword == "~*":
             # Accepts testing on all architectures. Valid if keywords contains either
             # testing or stable for any keyword
-            if any([not keyword.startswith("*") for keyword in keywords]):
+            if any(not keyword.startswith("*") for keyword in keywords):
                 return True
         elif keyword == "**":
             # Accepts any configuration
             return True
-        else:  # regular keyword
-            if keyword in keywords:
+        elif keyword.startswith("~"):
+            # Accepts testing on this architecture. Valid if keywords contains either
+            # testing or stable for this keyword
+            if accepts_testing(keyword[1:], keywords):
                 return True
+        else:  # regular keyword
+            if accepts_stable(keyword, keywords):
+                return True
+
+    return "**" in keywords
 
 
 def get_unstable_flag(mod: Pybuild) -> Optional[str]:
