@@ -9,11 +9,9 @@ import glob
 import os
 from collections import defaultdict
 from functools import lru_cache
-from typing import Dict, List, Mapping, Optional, Set, Tuple
+from typing import Dict, Iterable, List, Mapping, Optional, Set, Tuple
 
 from portmod.config import read_config
-from portmod.functools import prefix_aware_cache
-from portmod.globals import env
 from portmod.pybuild import Pybuild
 from portmodlib.atom import QualifiedAtom
 from portmodlib.parsers.list import read_list
@@ -32,7 +30,6 @@ from . import Repo, get_repo
 # Note: All repository files should be encoded as utf-8.
 
 
-@lru_cache()
 def __get_layout(repo_path: str) -> Dict:
     path = os.path.join(repo_path, "metadata", "layout.conf")
     if os.path.exists(path):
@@ -40,7 +37,6 @@ def __get_layout(repo_path: str) -> Dict:
     return {}
 
 
-@lru_cache()
 def get_master_names(repo_path: str) -> Set[str]:
     """Returns the direct masters for the repository at the given path"""
     masters = set()
@@ -76,9 +72,6 @@ def get_archs(repo: str) -> Set[str]:
     if os.path.exists(path):
         archs |= set(read_list(path, encoding="utf-8"))
 
-    for master in get_masters(repo):
-        archs |= get_archs(master.location)
-
     return archs
 
 
@@ -101,20 +94,23 @@ def get_global_use(repo) -> Dict[str, str]:
     return use
 
 
-@prefix_aware_cache
-def get_profiles(arch: str) -> Dict[str, List[Tuple[str, str, str]]]:
+def get_profiles(
+    arch: str, repos: Iterable[Repo]
+) -> Dict[str, List[Tuple[str, str, str]]]:
     """
     Returns the list of profiles available from all known repositories
 
     args:
         arch: Only profiles matching this architecture will be produced
+        repos: Only profiles from these repositories will be produced
 
     returns:
         A tuple containing the profile's path, name stability keyword
         and repository
     """
     profiles: Dict[str, List[Tuple[str, str, str]]] = defaultdict(list)
-    for repo in env.prefix().REPOS:
+
+    for repo in repos:
         path = os.path.join(repo.location, "profiles", "profiles.yaml")
         if os.path.exists(path):
             repo_profiles = parse_yaml_dict_dict(path)
@@ -167,10 +163,12 @@ def get_license_groups(repo: str) -> Dict[str, Set[str]]:
     @param repo: path to repository
     @returns set of license groups
     """
-    result = {}
+    result: Dict[str, Set[str]] = defaultdict(set)
 
     for master in get_masters(repo):
-        result.update(get_license_groups(master.location))
+        # Merge each set into the result. Licenses can only be added to groups
+        for group, licenses in get_license_groups(master.location).items():
+            result[group] |= licenses
 
     path = os.path.join(repo, "profiles", "license_groups.yaml")
     if os.path.exists(path):
@@ -178,15 +176,13 @@ def get_license_groups(repo: str) -> Dict[str, Set[str]]:
 
         for name, values in groups.items():
             if values is not None:
-                result[name] = set(values.split())
-            else:
-                result[name] = set()
+                result[name] |= set(values.split())
 
     def substitute(group: str):
         groups = []
-        for license in result[group]:
-            if license.startswith("@"):
-                groups.append(license)
+        for license_str in result[group]:
+            if license_str.startswith("@"):
+                groups.append(license_str)
         for subgroup in groups:
             result[group].remove(subgroup)
             substitute(subgroup.lstrip("@"))
