@@ -14,7 +14,7 @@ from portmodlib.l10n import l10n
 from .config import get_config
 from .globals import env
 from .repo import RemoteRepo, Repo, get_repo_name
-from .repo.metadata import get_master_names
+from .repo.metadata import get_archs, get_master_names
 
 
 def _iterate_repos_cfg(path: str):
@@ -150,4 +150,35 @@ def add_repo(repo: RemoteRepo) -> Optional[Repo]:
     return new_repo
 
 
+def get_remote_repos(arch: Optional[str] = None) -> Dict[str, RemoteRepo]:
+    """
+    Returns repositories declared by the repositories currently known
+    """
+    # Note: This method should not be cached, as new declarations may be
+    # added when synchronizing a repository, and may be immediately used by
+    # a repository synchronizing afterwards.
+    repos = {}
+    for repo in env.REPOS:
+        conf = os.path.join(repo.location, "metadata", "repos.cfg")
+        if os.path.exists(conf):
+            repos.update(
+                {
+                    remote_repo.name: remote_repo
+                    for remote_repo in parse_remote_repos(conf)
+                    if arch is None or arch in remote_repo.arch
+                }
+            )
+    for repo in env.REPOS:
+        if repo.name not in repos and arch in get_archs(repo.location):
+            repos[repo.name] = RemoteRepo(
+                name=repo.name,
+                sync_type=repo.sync_type,
+                sync_uri=repo.sync_uri,
+                priority=repo.priority,
+                description="Local repository in repos.cfg",
+                arch=get_archs(repo.location),
+            )
+    return repos
+
+
 env.REPOS = list(get_local_repos().values())
