@@ -10,21 +10,31 @@ from typing import Any, Iterable, Optional, Tuple
 
 from portmod.config.license import has_eula, is_license_accepted
 from portmod.repo.keywords import accepts, accepts_testing, get_keywords
-from portmodlib.atom import version_gt
+from portmodlib.atom import QualifiedAtom, version_gt
 
 from .globals import env
 from .pybuild import Pybuild
 
-KeywordDep = namedtuple("KeywordDep", ["atom", "keyword"])
+KeywordDep = namedtuple("KeywordDep", ["atom", "keyword", "masked"])
 LicenseDep = namedtuple("LicenseDep", ["atom", "license", "is_eula"])
 
 
+def is_keyword_masked(arch: str, keywords: Iterable[str]):
+    return "-" + arch in keywords or (
+        "-*" in keywords and arch not in keywords and "~" + arch not in keywords
+    )
+
+
 def get_keyword_dep(package: Pybuild) -> Optional[KeywordDep]:
     if not accepts(get_keywords(package.ATOM), package.KEYWORDS):
         arch = env.prefix().ARCH
         if accepts_testing(arch, package.KEYWORDS):
-            return KeywordDep(package.ATOM.CP, "~" + arch)
-        return KeywordDep("=" + package.ATOM.CP, "**")
+            return KeywordDep(QualifiedAtom(package.ATOM.CP), "~" + arch, False)
+        return KeywordDep(
+            QualifiedAtom("=" + package.ATOM.CP),
+            "**",
+            is_keyword_masked(arch, package.KEYWORDS),
+        )
     return None
 
 
@@ -62,7 +72,14 @@ def select_package(packages: Iterable[Pybuild]) -> Tuple[Pybuild, Any]:
     if not is_license_accepted(mod):
         return (mod, LicenseDep(mod.CPN, mod.LICENSE, has_eula(mod)))
     if keyword is not None:
-        return (mod, KeywordDep("=" + mod.ATOM.CPF, keyword))
+        return (
+            mod,
+            KeywordDep(
+                QualifiedAtom("=" + mod.ATOM.CPF),
+                keyword,
+                is_keyword_masked(env.prefix().ARCH, mod.KEYWORDS),
+            ),
+        )
 
     return (mod, None)
 
