@@ -60,19 +60,93 @@ T = TypeVar("T", bound="Atom")
 
 class Atom(str):
     CP: Optional[str]
+    """
+    The category, package name and version, excluding revision
+
+    E.g. ``base/example-suite-1.0``
+    """
     CPN: Optional[str]
+    """
+    The category and package name
+
+    E.g. ``base/example-suite``
+    """
     USE: Set[str] = set()
+    """
+    Use flags set on the atom.
+
+    E.g. ``{minimal}`` in ``base/example-suite[minimal]``
+    """
     P: str
+    """
+    The package name and version, excluding revision
+
+    E.g. ``example-suite-1.0``
+    """
     PN: str
+    """
+    The package name
+
+    E.g. ``example-suite``
+    """
     PF: str
+    """
+    The package name and version, including revision
+
+    E.g. ``example-suite-1.0-r1``
+    """
     PV: Optional[str]
+    """
+    The package version, not including revision
+
+    E.g. ``1.0``
+    """
     PR: Optional[str]
+    """
+    The package revision
+
+    E.g. ``r1``
+    """
     C: Optional[str]
+    """
+    The package category
+
+    E.g. ``base``
+    """
     R: Optional[str]
+    """
+    The package repository
+
+    E.g. ``openmw`` in base/example-suite-1.0-r1::openmw
+    """
     OP: Optional[str]
+    """
+    An operator.
+
+    See PMS section `8.2.6.1 <https://projects.gentoo.org/pms/7/pms.html#x1-760008.2.6.1>`_,
+    noting that Weak blocks are not currently supported by Portmod, and blocks don't show up
+    in OP (they instead set the BLOCK field).
+
+    E.g. ``openmw`` in base/example-suite-1.0-r1::openmw
+    """
     BLOCK: bool
+    """
+    If true, this atom is a blocker, referring to a package which must not be installed.
+
+    E.g. ``!!base/example-suite``
+    """
     PVR: Optional[str]
+    """
+    The version and revision
+
+    E.g. 1.0-r1
+    """
     CPF: str
+    """
+    The category, package name and version, including revision
+
+    E.g. ``base/example-suite-1.0-r1``
+    """
 
     _CACHE: Dict[str, Any] = {}
 
