@@ -8,7 +8,7 @@ import os
 import shutil
 from glob import iglob
 from logging import info, warning
-from typing import Callable, Iterable, List, Optional, Pattern, Set, Tuple, cast
+from typing import Callable, Iterable, List, Optional, Pattern, Set, Tuple, Union, cast
 
 from portmodlib.atom import Atom
 from portmodlib.colour import blue, magenta
@@ -69,13 +69,13 @@ class Pybuild1(FullPybuild):
 
     __file__ = __file__
 
-    M: Atom
+    P: Atom
     """
     The package name and version. [1]_
 
     E.g.: ``example-suite-1.0``
     """
-    MF: Atom
+    PF: Atom
     """
     The package name with version and revision. [1]_
 
@@ -93,13 +93,13 @@ class Pybuild1(FullPybuild):
 
     E.g. ``base``
     """
-    MV: str
+    PV: str
     """
     The package's version without revision [1]_
 
     E.g. ``1.0``
     """
-    MR: str
+    PR: str
     """
     The package's revision [1]_
 
@@ -107,7 +107,7 @@ class Pybuild1(FullPybuild):
 
     Is equal to ``r0`` is no revision is specified
     """
-    MVR: str
+    PVR: str
     """
     The package's version and revision [1]_
 
@@ -638,7 +638,7 @@ class Pybuild1(FullPybuild):
     def pkg_prerm(self):
         pass
 
-    def unpack(self, archives: Iterable[Source]):
+    def unpack(self, archives: Union[str, Iterable[Union[Source, str]]]):
         """
         Unpacks the given archive into the workdir
 
@@ -648,9 +648,19 @@ class Pybuild1(FullPybuild):
         # Slow import
         import patoolib
 
+        if isinstance(archives, str):
+            archives = [archives]
+
         for archive in archives:
-            info(">>> " + l10n("pkg-unpacking-source", archive=archive.name))
-            archive_name, ext = os.path.splitext(os.path.basename(archive.name))
+            if isinstance(archive, str):
+                name = archive
+                path = archive
+            else:
+                path = archive.path
+                name = archive.name
+
+            info(">>> " + l10n("pkg-unpacking-source", archive=name))
+            archive_name, ext = os.path.splitext(os.path.basename(name))
             # Hacky way to handle tar.etc having multiple extensions
             if archive_name.endswith("tar"):
                 archive_name, _ = os.path.splitext(archive_name)
@@ -661,7 +671,7 @@ class Pybuild1(FullPybuild):
             else:
                 verbosity = 0
             patoolib.extract_archive(
-                archive.path, outdir=outdir, interactive=False, verbosity=verbosity
+                path, outdir=outdir, interactive=False, verbosity=verbosity
             )
 
     def src_unpack(self):
