@@ -49,7 +49,7 @@ def set_test_repo():
     env.prefix().REPOS = [TEST_REPO]
 
 
-def setup_env(profile):
+def setup_env(profile, directory: Optional[str] = None):
     """
     Sets up an entire testing environment
     All file writes will occur within a temporary directory as a result
@@ -70,7 +70,7 @@ def setup_env(profile):
     env.DATA_DIR = os.path.join(TESTDIR, "local")
     env.__init__()  # type: ignore
     if "test" not in get_prefixes():
-        add_prefix("test", "test")
+        add_prefix("test", "test", directory)
         get_prefixes.cache_clear()
     env.set_prefix("test")
 
@@ -84,6 +84,8 @@ def setup_env(profile):
     gitrepo.config_writer().set_value("user", "name", "pytest").release()
     os.makedirs(TESTDIR, exist_ok=True)
     os.makedirs(os.path.join(TESTDIR, "local"), exist_ok=True)
+    os.makedirs(os.path.join(TESTDIR, "work"), exist_ok=True)
+    os.chdir(os.path.join(TESTDIR, "work"))
     set_test_repo()
     sync(env.REPOS)
     set_test_repo()
@@ -93,7 +95,7 @@ def setup_env(profile):
     with open(env.prefix().CONFIG, "a") as file:
         print('REPOS = "test"', file=file)
 
-    os.environ["INSTALL_DEST"] = str(get_config()["INSTALL_DEST"])
+    get_config()
     return {
         "testdir": TESTDIR,
         "config": f"{TESTDIR}/config.cfg",
