@@ -1,4 +1,4 @@
-# Copyright 2019-2020 Portmod Authors
+# Copyright 2019-2021 Portmod Authors
 # Distributed under the terms of the GNU General Public License v3
 
 """
@@ -28,7 +28,7 @@ def test_masters_esp():
 
     configure(["test/quill-of-feyfolken-2.0.2"], no_confirm=True)
     path = os.path.join(
-        env.prefix().ROOT, "test", "quill-of-feyfolken", "Quill of Feyfolken.esp"
+        env.prefix().ROOT, "pkg", "test", "quill-of-feyfolken", "Quill of Feyfolken.esp"
     )
     masters = get_masters(path)
     assert len(masters) == 1
