@@ -7,6 +7,7 @@ Tests the mod selection system
 
 import io
 import sys
+from collections import defaultdict
 from contextlib import redirect_stdout
 from io import StringIO
 
@@ -58,9 +59,12 @@ def test_display_results():
     Tests that display_search_results doesn't cause any exceptions
     and that all mods are included in the result
     """
-    results = query("LICENSE", "")
+    results = list(query("LICENSE", ""))
+    grouped = defaultdict(list)
+    for result in results:
+        grouped[result.CPN].append(result)
     strfile = io.StringIO()
-    display_search_results(results, file=strfile)
+    display_search_results(list(grouped.values()), file=strfile)
     string = strfile.getvalue()
     for mod in results:
         assert mod.ATOM.CPN in string
